#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
  django_excel_export : Export your django database into Excel documents
  (C)2010 - Apidev - http://www.apidev.fr
  This is distributed under GNU LGPL license, see license.txt
"""

from django.contrib import admin
import models
from django.contrib.admin.widgets import AdminTextInputWidget
from django.utils.safestring import mark_safe
from django.core.urlresolvers import reverse

class ExportWidget(AdminTextInputWidget):
    def render(self, name, value, attrs=None):
        widget = super(ExportWidget, self).render(name, value, attrs)
        base_url = reverse('excel_export.views.export', kwargs={'name':'##'})
        base_url = base_url[:-2]
        button_code = u"""&nbsp;&nbsp;<input type="button" value="Export"
                        onclick="window.open(\'{0}\'+document.getElementById(\'{1}\').value)" />""".format(base_url, attrs['id'])
        return mark_safe(u'{0}'.format(widget)+button_code)

class ColumnInline(admin.TabularInline):
    model = models.Column
    
class FilterInline(admin.TabularInline):
    model = models.Filter

class ExportAdmin(admin.ModelAdmin):
    save_on_top = True
    inlines = (ColumnInline, FilterInline)
    if models.EXCEL_REPORT_VIEWS:
        list_display = ['name', 'table', 'report']
        list_filter = ['report', 'table']    
        fieldsets = (
            ('Informations générales', {
                'classes': ('wide'),
                'fields': ('name', 'table', 'report')                  
            }),        
        )
    else:
        list_display = ['name', 'table']
        list_filter = ['table']    
        fieldsets = (
            ('Informations générales', {
                'classes': ('wide'),
                'fields': ('name', 'table')                  
            }),        
        )
    search_fields = ['name']
                      
    
    def formfield_for_dbfield(self, db_field, **kwargs):        
        if db_field.name == 'name':
            kwargs['widget'] = ExportWidget
            try:
                del kwargs['request']
            except KeyError:
                pass
            return db_field.formfield(**kwargs)
        return super(ExportAdmin,self).formfield_for_dbfield(db_field, **kwargs)


admin.site.register(models.Export, ExportAdmin)
