#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
  django_excel_export : Export your django database into Excel documents
  (C)2010 - Apidev - http://www.apidev.fr
  This is distributed under GNU LGPL license, see license.txt
"""

from django.db import models
from django.conf import settings
from django.forms.fields import RegexField
import re
from django.utils.translation import ugettext_lazy as _
from django.utils.translation import ugettext as __

class NoSpaceCharFormField(RegexField):
    """Validation of URLS"""
    default_error_messages = {
        'invalid': _(u"No space allowed"),
    }
    validation_regex = re.compile(r'^[-\w\.]*$')

    def __init__(self, *args, **kwargs):
        super(NoSpaceCharFormField, self).__init__(NoSpaceCharFormField.validation_regex, *args, **kwargs)

class NoSpaceCharField(models.CharField):
    def __init__(self, verbose_name=None, name=None, **kwargs):
        kwargs['max_length'] = kwargs.get('max_length', 200)
        models.CharField.__init__(self, verbose_name, name, **kwargs)

    def formfield(self, **kwargs):
        defaults = {'form_class': NoSpaceCharFormField}
        defaults.update(kwargs)
        return super(NoSpaceCharField, self).formfield(**defaults)

try:
    from south.modelsinspector import add_introspection_rules
    add_introspection_rules([], ["excel_export\.models\..*NoSpaceCharField"])
except:
    pass

def get_project_tables():
    """returns the database table names used the current project"""
    try:
        exportable_apps = settings.EXCEL_EXPORTABLE_APPS
    except:
        exportable_apps = []
        
    from django.db import connection
    tables = connection.introspection.table_names()
    seen_models = connection.introspection.installed_models(tables)
    choice = []
    for m in seen_models:
        s = unicode(m)
        sp = s.find("'")
        ep = s.find("'", sp+1)
        s = s[sp+1:ep]
        try:
            x = s.split('.')
            app, table = x[-3], x[-1]
            if not ((len(exportable_apps)>0) and (not app in exportable_apps)):  
                v = app+'.'+table
                choice.append((v, m._meta.verbose_name.capitalize()))
        except Exception, msg:
            pass #print msg, s
    choice.sort()
    return tuple(choice)

# Create your models here.

try:
    EXCEL_REPORT_VIEWS = settings.EXCEL_REPORT_VIEWS
except AttributeError:
    EXCEL_REPORT_VIEWS = ()
        
class Export(models.Model):
    name = NoSpaceCharField(max_length=40, unique=True)
    table = models.CharField(max_length=40, choices=get_project_tables(),
                             default='', blank=True, null=True)
    report = models.CharField(max_length=100, choices=EXCEL_REPORT_VIEWS,
                              default='', blank=True, null=True)

    class Meta:
        ordering = ['name']
        permissions = (('can_export', 'Can export'),)
    
    def __unicode__(self):
        return self.name

class Column(models.Model):
    col = models.CharField(max_length=40)
    label = models.CharField(max_length=40, blank=True)
    ordering = models.IntegerField(default=1)
    export = models.ForeignKey(Export)

    def __unicode__(self):
        return self.label if self.label else self.col
    
    class Meta:
        ordering=['ordering']

class Filter(models.Model):
    LOOKUP_CHOICES = (
        (u'exact', u'égal'),
        (u'iexact', u'égal (aA)'),
        (u'contains', u'contient'),
        (u'icontains', u'contient (aA)'),
        (u'gt', u'plus grand'),
        (u'gte', u'plus grand ou égal'),
        (u'lt', u'plus petit'),
        (u'lte', u'plus petit ou égal'),
        (u'startswith', u'commence par'),
        (u'istartswith', u'commence par (aA)'),
        (u'endswith', u'se termine par'),
        (u'iendswith', u'se termine par (aA)'),
        (u'isnull', u'pas de valeur (True/False)'),
    )
    
    col = models.CharField(max_length=40)
    value = models.CharField(max_length=40)
    lookup = models.CharField(max_length=40, choices=LOOKUP_CHOICES, default='exact')
    ordering = models.IntegerField(default=1)
    export = models.ForeignKey(Export)

    def __unicode__(self):
        return u'{0}={1}'.format(self.col, self.value)
    
    class Meta:
        ordering=['ordering']
